@@ -11,7 +11,7 @@ neighbors <- function(x,n,tvectors=tvectors,breakdown=TRUE){
     if(class(x) == "character"){
       
       if(breakdown==TRUE){satz1 <- breakdown(x)}  
-      if(breakdown==TRUE){satz1 <- x} 
+      if(breakdown==FALSE){satz1 <- x} 
       
       satz1split <- strsplit(satz1,split=" ")[[1]]
       
